# Change Log

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.6.35] - 2021-05-29
- display f/r/w column to show the errors from frozen / read io / write io errors. Because there are things that needed to be done from monitoring the issue.
- fix api bugs

## [0.5.94] - 2021-05-2
- tidy up function. remove the tmp files that is not used or opened by the process
- space management. check periodically for the critical space alerts. when the disk is less than 1 GB there will be an alert and trigger for the space clean up management.

## [0.4.20] - 2020-05-05
- api support

## [0.3.3] - 2020-02-07
- revamp interactive window
- check disk size on tmp folder and preventing them to fail
- check window console and prevent error
- enable background operation when the workers is not on focus

## [0.1.1] - 2020-02-07

### Fixed
- Find jobs more reliably by inspecting cmdline instead of "process name"
- checked-in config.yaml now conforms to code's expectations!

### Added
- Job progress histogram view in `interactive` mode
- Ability to disable archival (by commenting out the config section)
- Minor improvements to messages, titles, tables in interactive mode

## [0.1.0] - 2020-01-31

### Fixed
- Fixed issue with prioritization of tmp dirs

## [0.0.1] - 2020-01-30

### Added
- `.gitignore` and `CHANGELOG.md`
